@@ -199,7 +199,10 @@ def warden_metadata():
     for alias in specter_data['wallets_alias']:
         # Line below throws an error when specter is not loaded yet
         meta['txs'][alias] = get_specter_tx(alias)
-        meta['scan'][alias] = current_app.wallets[alias]['scan']
+        try:
+            meta['scan'][alias] = current_app.wallets[alias]['scan']
+        except TypeError:
+            meta['scan'][alias] = None
 
     meta['full_df'] = specter_df()
 
